@@ -72,6 +72,17 @@ class OutscaleGateway:
         else:
             self.retry = 1
 
+    def update_credentials(self, region=None, profile=None, access_key=None,
+                           secret_key=None, email=None, password=None):
+        """
+        destroy and create a new credential map use for each call.
+        so you can change your ak/sk, region without having to recreate the whole Gateway
+        as the object is recreate, you can't expect to keep parameter from the old configuration
+        example: just updating the password, without renter the login will fail
+        """
+        self.call.update_credentials(region=region, profile=profile, access_key=access_key,
+                                     secret_key=secret_key, email=email, password=password)
+
     def _convert(self, input_file):
         structure = {}
         try:
